<?php
/**
 * Image with Ornament widget.
 *
 * @package woondershop-pt
 */

if ( ! class_exists( 'PW_Image_With_Ornament' ) ) {
	class PW_Image_With_Ornament extends WP_Widget {
		private $widget_id_base, $widget_name, $widget_description, $widget_class;

		public function __construct() {
			$this->widget_id_base     = 'image_with_ornament';
			$this->widget_class       = 'widget-image-with-ornament';
			$this->widget_name        = esc_html__( 'Image with Ornament', 'woondershop-pt' );
			$this->widget_description = esc_html__( 'Image with ornament on different positions.', 'woondershop-pt' );

			parent::__construct(
				'pw_' . $this->widget_id_base,
				sprintf( 'ProteusThemes: %s', $this->widget_name ),
				array(
					'description' => $this->widget_description,
					'classname'   => $this->widget_class,
				)
			);
		}

		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args widget arguments.
		 * @param array $instance widget data.
		 */
		public function widget( $args, $instance ) {
			$image = empty( $instance['image'] ) ? '' : $instance['image'];
			$position = empty( $instance['position'] ) ? 'left' : $instance['position'];

			echo $args['before_widget'];
			?>
			<div class="image-with-ornament  image-with-ornament--<?php echo esc_attr( $position ); ?>">
				<img src="<?php echo esc_url( $image ); ?>" alt="Image with ornament">
			</div>
			<?php
			echo $args['after_widget'];
		}

		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @param array $new_instance The new options.
		 * @param array $old_instance The previous options.
		 */
		public function update( $new_instance, $old_instance ) {
			$instance = array();

			$instance['image']    = esc_url_raw( $new_instance['image'] );
			$instance['position'] = sanitize_key( $new_instance['position'] );

			return $instance;
		}

		/**
		 * Back-end widget form.
		 *
		 * @param array $instance The widget options.
		 */
		public function form( $instance ) {
			$image    = empty( $instance['image'] ) ? '' : $instance['image'];
			$position = empty( $instance['position'] ) ? 'left' : $instance['position'];
			?>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>"><?php esc_html_e( 'Picture URL:', 'woondershop-pt' ); ?></label>
				<input class="widefat" style="margin-bottom: 6px;" id="<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'image' ) ); ?>" type="text" value="<?php echo esc_attr( $image ); ?>" />
				<input type="button" onclick="ProteusWidgetsUploader.imageUploader.openFileFrame('<?php echo esc_attr( $this->get_field_id( 'image' ) ); ?>');" class="button button-secondary" value="<?php esc_html_e( 'Upload Image', 'woondershop-pt' ); ?>" />
			</p>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'position' ) ); ?>"><?php esc_html_e( 'Position of the ornament:', 'woondershop-pt' ); ?></label>
				<select name="<?php echo esc_attr( $this->get_field_name( 'position' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'position' ) ); ?>">
					<option value="left" <?php selected( $position, 'left' ); ?>><?php esc_html_e( 'Left side', 'woondershop-pt' ); ?></option>
					<option value="right" <?php selected( $position, 'right' ); ?>><?php esc_html_e( 'Right side', 'woondershop-pt' ); ?></option>
				</select>
			</p>

			<?php
		}
	}
	register_widget( 'PW_Image_With_Ornament' );
}
